# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/moblyze/asset/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/moblyze/asset/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Moblyze\\Asset\\": "packages/moblyze/asset/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Moblyze\Asset\Providers\AssetServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Asset'  => Moblyze\Asset\Facades\Asset::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Moblyze\\AssetTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Moblyze\Asset\Providers\AssetServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Moblyze\Asset\Providers\AssetServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Moblyze\Asset\Providers\AssetServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/asset/{modulename}

**User**

    http://path-to-route-folder/user/asset/{modulename}

**Public**

    http://path-to-route-folder/assets


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/asset/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/asset/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/asset/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/asset/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/asset/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/asset/{modulename}/{slug}
    METHOD: GET