<?php

namespace Moblyze\Asset\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Moblyze\Asset\Interfaces\AssetRepositoryInterface;

class AssetPublicController extends BaseController
{
    // use AssetWorkflow;

    /**
     * Constructor.
     *
     * @param type \Moblyze\Asset\Interfaces\AssetRepositoryInterface $asset
     *
     * @return type
     */
    public function __construct(AssetRepositoryInterface $asset)
    {
        $this->repository = $asset;
        parent::__construct();
    }

    /**
     * Show asset's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $assets = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('asset::asset.names'))
            ->view('asset::public.asset.index')
            ->data(compact('assets'))
            ->output();
    }


    /**
     * Show asset.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $asset = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($asset->name . trans('asset::asset.name'))
            ->view('asset::public.asset.show')
            ->data(compact('asset'))
            ->output();
    }

}
