<?php

namespace Moblyze\Asset\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Moblyze\Asset\Http\Requests\EngineRequest;
use Moblyze\Asset\Interfaces\EngineRepositoryInterface;
use Moblyze\Asset\Models\Engine;
use Moblyze\Asset\Forms\Engine as Form;

/**
 * APIController  class for engine.
 */
class EngineAPIController extends BaseController
{

    /**
     * Initialize engine resource controller.
     *
     * @param type EngineRepositoryInterface $engine
     *
     * @return null
     */
    public function __construct(EngineRepositoryInterface $engine)
    {
        parent::__construct();
        $this->repository = $engine;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Moblyze\Asset\Repositories\Criteria\EngineResourceCriteria::class);
    }

    /**
     * Display a list of engine.
     *
     * @return Response
     */
    public function index(EngineRequest $request)
    {
        return $this->repository
            ->setPresenter(\Moblyze\Asset\Repositories\Presenter\EnginePresenter::class)
            ->paginate();
    }

    /**
     * Display engine.
     *
     * @param Request $request
     * @param Model   $engine
     *
     * @return Response
     */
    public function show(EngineRequest $request, Engine $engine)
    {
        return $engine->setPresenter(\Moblyze\Asset\Repositories\Presenter\EngineListPresenter::class);
        ;
    }

    /**
     * Create new engine.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(EngineRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('asset::engine.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('asset/engine/' . $engine->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('asset/engine');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the engine.
     *
     * @param Request $request
     * @param Model   $engine
     *
     * @return Response
     */
    public function update(EngineRequest $request, Engine $engine)
    {
        try {
            $data = $request->all();

            $engine->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('asset::engine.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('asset/engine/' . $engine->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('asset/engine/' . $engine->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the engine.
     *
     * @param Model   $engine
     *
     * @return Response
     */
    public function destroy(EngineRequest $request, Engine $engine)
    {
        try {
            $engine->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('asset::engine.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('asset/engine/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('asset/engine/' . $engine->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
