<?php

namespace Moblyze\Asset\Providers;

use Illuminate\Support\ServiceProvider;

class AssetServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'asset');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'asset');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerAsset();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerAsset()
    {
        $this->app->bind('asset', function($app) {
            return new Asset($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Asset', 'Lavalite\Asset\Facades\Asset');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('moblyze.asset', function ($app) {
            return $this->app->make('Moblyze\Asset\Asset');
        });

        // Bind Asset to repository
        $this->app->bind(
            'Moblyze\Asset\Interfaces\AssetRepositoryInterface',
            \Moblyze\Asset\Repositories\Eloquent\AssetRepository::class
        );
        // Bind Engine to repository
        $this->app->bind(
            'Moblyze\Asset\Interfaces\EngineRepositoryInterface',
            \Moblyze\Asset\Repositories\Eloquent\EngineRepository::class
        );

        $this->app->register(\Moblyze\Asset\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Moblyze\Asset\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and asset's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'moblyze.asset'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeAsset::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['moblyze.asset'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('moblyze/asset.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/asset')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/asset')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
